@@ -1,6 +1,6 @@
 package XML::NewsML_G2::Scheme;
 
-# $Id: Scheme.pm 46640 2013-06-07 15:16:57Z apatecgortan $
+# $Id: Scheme.pm 46929 2013-06-25 08:32:49Z apatecgortan $
 
 use Moose;
 use namespace::autoclean;
@@ -10,6 +10,12 @@ has 'alias', isa => 'Str', is => 'ro', required => 1;
 has 'uri', isa => 'Str', is => 'ro';
 has 'catalog', isa => 'Str', is => 'ro';
 
+sub BUILD {
+    my $self = shift;
+    die "Either uri or catalog is required\n" unless ($self->uri or $self->catalog);
+    return;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
