@@ -1,6 +1,6 @@
 package XML::NewsML_G2::Writer;
 
-# $Id: Writer.pm 46693 2013-06-11 08:28:45Z apatecgortan $
+# $Id: Writer.pm 46997 2013-06-28 13:25:06Z apatecgortan $
 
 use Moose;
 use DateTime;
@@ -13,8 +13,8 @@ has 'news_item', isa => 'XML::NewsML_G2::News_Item', is => 'ro', required => 1;
 has 'encoding', isa => 'Str', is => 'ro', default => 'utf-8';
 has 'generator', isa => 'Str', is => 'ro', default => __PACKAGE__;
 
-has 'scheme_manager', isa => 'XML::NewsML_G2::Scheme_Manager', is => 'ro', lazy_build => 1; 
-has 'doc', isa => 'XML::LibXML::Document', is => 'ro', lazy_build => 1;
+has 'scheme_manager', isa => 'XML::NewsML_G2::Scheme_Manager', is => 'ro', lazy => 1, builder => '_build_scheme_manager'; 
+has 'doc', isa => 'XML::LibXML::Document', is => 'ro', lazy=> 1, builder => '_build_doc';
 has '_formatter', is => 'ro', default => sub {DateTime::Format::XSD->new()};
 
 has 'g2_ns', isa => 'Str', is => 'ro', default => 'http://iptc.org/std/nar/2006-10-01/';
@@ -454,7 +454,7 @@ __END__
 =head1 NAME
 
 XML::NewsML_G2::Writer - base class for XML DOM tree creation
-conforming to NewsML G2
+conforming to NewsML-G2
 
 =head1 SYNOPSIS
 
@@ -497,7 +497,7 @@ L<XML::LibXML::Document> instance used to create the output document
 
 =item g2_ns
 
-XML Namespace of NewsML G2
+XML Namespace of NewsML-G2
 
 =item xhtml_n2
 
@@ -533,7 +533,10 @@ C<paragraphs> element of the L<XML::NewsML_G2::News_Item>.
 
 =item create_dom
 
-Returns the L<XML::LibXML::Document> element containing the requested output.
+Returns the L<XML::LibXML::Document> element containing the requested
+output. Be careful I<not> to use C<< $dom->serialize(2) >> for formatting,
+as this creates invalid NewsML-G2 files because it adds whitespace
+where none is allowed (e.g. in xs:dateTime elements).
 
 =back
 
